@@ -22,40 +22,45 @@ import logging
 
 
 class Source:
-    """ This is a basic source class for s-tui"""
+    """This is a basic source class for s-tui"""
+
     def __init__(self):
         self.edge_hooks = []
-        self.measurement_unit = ''
+        self.measurement_unit = ""
         self.last_measurement = []
         self.is_available = True
         self.available_sensors = []
-        self.name = ''
-        self.pallet = ('temp light', 'temp dark',
-                       'temp light smooth', 'temp dark smooth')
+        self.name = ""
+        self.pallet = (
+            "temp light",
+            "temp dark",
+            "temp light smooth",
+            "temp dark smooth",
+        )
         self.alert_pallet = None
 
     def update(self):
-        """ Updates the last measurement, invokes hooks if present """
+        """Updates the last measurement, invokes hooks if present"""
         self.eval_hooks()
 
     def get_maximum(self):
-        """ Returns the maximum measurement as measured so far """
+        """Returns the maximum measurement as measured so far"""
         raise NotImplementedError("Get maximum is not implemented")
 
     def get_top(self):
-        """ Returns higest theoretical value the sensors can reach """
+        """Returns highest theoretical value the sensors can reach"""
         raise NotImplementedError("get_top is not implemented")
 
     def get_is_available(self):
-        """ Returns is_available """
+        """Returns is_available"""
         return self.is_available
 
     def reset(self):
-        """ Resets source state, e.g. current max """
+        """Resets source state, e.g. current max"""
         raise NotImplementedError("Reset is not implemented")
 
     def get_sensors_summary(self):
-        """ This returns a dict of sensor of the source and their values """
+        """This returns a dict of sensor of the source and their values"""
         sub_title_list = self.get_sensor_list()
 
         graph_vector_summary = OrderedDict()
@@ -66,39 +71,38 @@ class Source:
         return graph_vector_summary
 
     def get_summary(self):
-        """ Returns a dict of source name and sensors with their values """
+        """Returns a dict of source name and sensors with their values"""
         graph_vector_summary = OrderedDict()
-        graph_vector_summary[self.get_source_name()] = (
-            '[' + self.measurement_unit + ']')
+        graph_vector_summary[self.get_source_name()] = "[" + self.measurement_unit + "]"
         graph_vector_summary.update(self.get_sensors_summary())
         return graph_vector_summary
 
     def get_source_name(self):
-        """ Returns source name """
+        """Returns source name"""
         return self.name
 
     def get_edge_triggered(self):
-        """ Returns true if a measurement was higher than some thershhold"""
+        """Returns true if a measurement was higher than some thershhold"""
         raise NotImplementedError("Get Edge triggered not implemented")
 
     def get_measurement_unit(self):
-        """ Returns measurement unit of source """
+        """Returns measurement unit of source"""
         return self.measurement_unit
 
     def get_pallet(self):
-        """ Returns the pallet of the source for graph plotting """
+        """Returns the pallet of the source for graph plotting"""
         return self.pallet
 
     def get_alert_pallet(self):
-        """ Returns the 'alert' pallet for graph plotting """
+        """Returns the 'alert' pallet for graph plotting"""
         return self.alert_pallet
 
     def get_sensor_list(self):
-        """ Returns list of a available sensors for source """
+        """Returns list of a available sensors for source"""
         return self.available_sensors
 
     def get_reading_list(self):
-        """ Returns a list of the last measurement """
+        """Returns a list of the last measurement"""
         return self.last_measurement
 
     def add_edge_hook(self, hook):
@@ -124,12 +128,13 @@ class Source:
 
 
 class MockSource(Source):
-    """ Mock class for testing """
+    """Mock class for testing"""
+
     def get_maximum(self):
         return 20
 
     def get_summary(self):
-        return {'MockValue': 5, 'Tahat': 34}
+        return {"MockValue": 5, "Tahat": 34}
 
     def get_edge_triggered(self):
         raise NotImplementedError("Get Edge triggered not implemented")
