@@ -27,7 +27,8 @@ import urwid
 
 
 class ScalableBarGraph(urwid.BarGraph):
-    """Scale the graph acording to screen size"""
+    """Scale the graph according to screen size"""
+
     _size = (0, 0)
 
     def render(self, size, focus=False):
@@ -50,8 +51,7 @@ class ScalableBarGraph(urwid.BarGraph):
         (maxcol, _) = size
 
         if self.bar_width is not None:
-            return [self.bar_width] * min(
-                len(bardata), int(maxcol / self.bar_width))
+            return [self.bar_width] * min(len(bardata), int(maxcol / self.bar_width))
 
         if len(bardata) >= maxcol:
             return [1] * maxcol
@@ -74,21 +74,16 @@ class ScalableBarGraph(urwid.BarGraph):
 
 
 class LabeledBarGraphVector(urwid.WidgetPlaceholder):
-    """Add option to add labels for X and Y axes """
+    """Add option to add labels for X and Y axes"""
 
-    def __init__(self,
-                 title,
-                 sub_title_list,
-                 y_label,
-                 bar_graph_vector,
-                 visible_graph_list):
+    def __init__(
+        self, title, sub_title_list, y_label, bar_graph_vector, visible_graph_list
+    ):
         for bar_graph in bar_graph_vector:
             if not isinstance(bar_graph, ScalableBarGraph):
-                raise Exception(
-                    'graph vector items must be ScalableBarGraph')
+                raise Exception("graph vector items must be ScalableBarGraph")
         if not self.check_label(y_label):
-            raise Exception(
-                'Y label must be a valid label')
+            raise Exception("Y label must be a valid label")
 
         self.visible_graph_list = visible_graph_list
         self.bar_graph_vector = []
@@ -117,7 +112,7 @@ class LabeledBarGraphVector(urwid.WidgetPlaceholder):
         if not y_label:
             text = urwid.Text("1")
             pile = urwid.Pile([urwid.ListBox([text])])
-            self.y_label = ('fixed', 1, pile)
+            self.y_label = ("fixed", 1, pile)
             return
 
         str_y_label = [str(i) for i in y_label]
@@ -130,27 +125,26 @@ class LabeledBarGraphVector(urwid.WidgetPlaceholder):
         y_list_walker = urwid.Pile(y_list_walker, focus_item=0)
         y_scale_len = len(max(str_y_label, key=len))
 
-        self.y_label = ('fixed', y_scale_len, y_list_walker)
+        self.y_label = ("fixed", y_scale_len, y_list_walker)
 
     def set_visible_graphs(self, visible_graph_list=None):
         """Show a column of the graph selected for display"""
         if visible_graph_list is None:
             visible_graph_list = self.visible_graph_list
 
-        vline = urwid.AttrWrap(urwid.SolidFill(u'|'), 'line')
+        vline = urwid.AttrWrap(urwid.SolidFill("|"), "line")
 
         graph_vector_column_list = []
-        for state, graph, sub_title in zip(visible_graph_list,
-                                           self.bar_graph_vector,
-                                           self.sub_title_list):
+        for state, graph, sub_title in zip(
+            visible_graph_list, self.bar_graph_vector, self.sub_title_list
+        ):
             if state:
-                text_w = urwid.Text(sub_title, align='center')
+                text_w = urwid.Text(sub_title, align="center")
                 sub_title_widget = urwid.ListBox([text_w])
-                graph_a = [('fixed', 1, sub_title_widget),
-                           ('weight', 1, graph)]
+                graph_a = [("fixed", 1, sub_title_widget), ("weight", 1, graph)]
                 graph_and_title = urwid.Pile(graph_a)
-                graph_vector_column_list.append(('weight', 1, graph_and_title))
-                graph_vector_column_list.append(('fixed', 1, vline))
+                graph_vector_column_list.append(("weight", 1, graph_and_title))
+                graph_vector_column_list.append(("fixed", 1, vline))
 
         # if all sub graph are disabled
         if not graph_vector_column_list:
@@ -161,14 +155,14 @@ class LabeledBarGraphVector(urwid.WidgetPlaceholder):
         # remove the last vertical line separator
         graph_vector_column_list.pop()
 
-        y_label_a = ('weight', 1, urwid.Columns(graph_vector_column_list))
-        y_label_and_graphs = [self.y_label,
-                              y_label_a]
+        y_label_a = ("weight", 1, urwid.Columns(graph_vector_column_list))
+        y_label_and_graphs = [self.y_label, y_label_a]
         column_w = urwid.Columns(y_label_and_graphs, dividechars=1)
         y_label_and_graphs_widget = urwid.WidgetPlaceholder(column_w)
 
-        init_widget = urwid.Pile([('fixed', 1, self.title),
-                                  ('weight', 1, y_label_and_graphs_widget)])
+        init_widget = urwid.Pile(
+            [("fixed", 1, self.title), ("weight", 1, y_label_and_graphs_widget)]
+        )
 
         self.visible_graph_list = visible_graph_list
         self.original_widget = init_widget
@@ -178,8 +172,7 @@ class LabeledBarGraphVector(urwid.WidgetPlaceholder):
 
     @staticmethod
     def check_label(label):
-        if (len(label) >= 2 and not(None in label) or
-                not label or label is None):
+        if len(label) >= 2 and not (None in label) or not label or label is None:
             return True
 
         return False
